@@ -1,4 +1,4 @@
-import pygame as pg
+import pygame
 pg.init()
 
 def init_pygame():
